@@ -81,13 +81,7 @@ class HandlerInterface(DefaultContentPage):
                 return calculate_hash_binary(binary)
 
     def get_streams(self):
-        if "Text" not in self.streams:
-            if self.response is not None:
-                self.streams["Text"] = self.response.get_text()
-
-                if self.streams["Text"] is None:
-                    self.streams["Binary"] = self.response.get_binary()
-        return self.streams
+        self.streams["Default"] = self.response
 
     def get_contents_body_hash(self):
         return self.get_contents_hash()
